<?php

namespace EventPortal\Domain\Util;

use Inertia\Inertia;
use Inertia\Response;

class Render
{
    /** @var array */
    protected $data;

    /** @var string */
    protected $component;

    /** @var string */
    protected $context;

    public function __construct(string $component, string $context)
    {
        $this->component = $component;
        $this->context = $context;
    }

    public function get(): Response
    {
        return Inertia::render($this->component, $this->data ?? []);
    }

    public function key(string $key): self
    {
        $this->data['pageHeader'] = config("page-headers.{$this->context}.{$key}", []);

        return $this;
    }

    public function withForm(array $form): self
    {
        $this->data['form'] = $form;

        return $this;
    }

    public function withForms(array $forms): self
    {
        $existingForms = $this->data['forms'] ?? [];

        $this->data['forms'] = array_merge($existingForms, $forms);

        return $this;
    }

    public function withTitle(string $title): self
    {
        $this->data['pageHeader']['title'] = $title;

        return $this;
    }

    /**
     * Generic data prop, not compatible with withTable method
     *
     * @param mixed $data
     */
    public function withData($data): self
    {
        $this->data['data'] = $data;

        return $this;
    }

    public function attributes(array $attributes): self
    {
        $this->data = array_replace_recursive($this->data, $attributes);

        return $this;
    }

    public function getData(): array
    {
        return $this->data;
    }
}
